#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-client
version:              0.7.8
visibility:           public
id:                   http-client-0.7.8-9CCfo3vVp8P3jNF4QXUQLt
key:                  http-client-0.7.8-9CCfo3vVp8P3jNF4QXUQLt
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/http-client
synopsis:             An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.

category:             Network
abi:                  ee33917d3b6af836682a26bebee674ce
exposed:              True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData

hidden-modules:
    Network.HTTP.Client.Body Network.HTTP.Client.Connection
    Network.HTTP.Client.Cookies Network.HTTP.Client.Core
    Network.HTTP.Client.Headers Network.HTTP.Client.Manager
    Network.HTTP.Client.Request Network.HTTP.Client.Response
    Network.HTTP.Client.Types Network.HTTP.Client.Util
    Network.HTTP.Proxy Network.PublicSuffixList.Lookup
    Network.PublicSuffixList.Types Network.PublicSuffixList.Serialize
    Network.PublicSuffixList.DataStructure Data.KeyedPool

import-dirs:          /usr/lib/ghc-8.10.5/site-local/http-client-0.7.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/http-client-0.7.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/http-client-0.7.8
hs-libraries:         HShttp-client-0.7.8-9CCfo3vVp8P3jNF4QXUQLt
depends:
    array-0.5.4.0 base-4.14.2.0
    base64-bytestring-1.2.0.1-Gn2QlQL7quxDmGBEoLUsKs
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    case-insensitive-1.2.1.0-6tEs2ust6UoJNkdDoolIXx containers-0.6.4.1
    cookie-0.4.5-DRjKUovO6l159RRdguKqPl deepseq-1.4.4.0
    exceptions-0.10.4 filepath-1.4.2.1 ghc-prim-0.6.1
    http-types-0.12.3-Di0Av9jbzuQGAtr7LDgLEc
    iproute-1.7.11-6uPNyAONr80CN3QPbOhxF5
    mime-types-0.1.0.9-2ORfbvGCmlz3ckhb8dUDtI
    network-3.1.2.2-DhUKX0ZpAd35HJ7CPbrOZd
    network-uri-2.6.4.1-FvgDgWAahTMJnOZjiFXR50
    random-1.2.0-BSVdQCE475yEKcUUPfL4ub stm-2.5.0.1
    streaming-commons-0.2.2.1-ECkYijsiekA4Fkarkvgqnu text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html:         /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

